package se.jernlas.gemexample;
import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextArea;

import se.jernlas.swing.gem.Gem;
import se.jernlas.swing.gem.types.TextType;

/**
 * A simple example application meant to examplify how to use the Gem-component.
 * 
 * @author jernlas
 */
class ExampleWindow extends JFrame {

   /**
    * Horizontal gap between components
    */
   private static final int  H_GAP               = 4;
   
   /**
    * Vertical gap between components
    */
   private static final int  V_GAP               = 4;

   /**
    * Serial version
    */
   private static final long serialVersionUID    = 20101126L;

   /**
    * The TextField containing the text that is to be analyzed by the gem.
    */
   private final JTextArea  textToAnalyze       = new JTextArea();
   
   /**
    * A label prompting the user to start typing in <code>textToAnalyze</code>
    */
   private final JLabel      textToAnalyzePrompt = new JLabel("Skriv något:");
   
   /**
    * The actual gem that gives the user feedback on his typing
    */
   private final Gem         gemAnalyzer         = new Gem(textToAnalyze
                                                       .getDocument());

   /**
    * Creates a standard example frame with a simple 
    * textfield component that is analyzed by a gem.
    */
   public ExampleWindow() {
      setDefaultCloseOperation(DISPOSE_ON_CLOSE);
      
      setLayout(new FlowLayout(FlowLayout.LEFT, H_GAP, V_GAP));
      
      add(textToAnalyzePrompt);
      
      add(textToAnalyze);
      textToAnalyze.setPreferredSize(new Dimension(100, 10*(int)textToAnalyze.getPreferredSize().getHeight()));
      
      add(gemAnalyzer);
      gemAnalyzer.setPreferredSize(new Dimension(50, 50));
      gemAnalyzer.addTextType(TextType.FORMAL_LETTER);
      gemAnalyzer.addTextType(TextType.INFORMAL_LETTER);
      
      pack();
      setVisible(true);
   }

}
