package se.jernlas.swing.gem;

/**
 * 
 * Any text that can be analyzed by a <code>TextAnalyzer</code>. This interface
 * provides two vital functions: 
 * <ul>
 * <li>A uniform interface for getting the text to analyze 
 * (<code>getText()</code>).</li>
 * <li>Forces the client to accept TextAnalyzers, resembling the 
 * Observer in the well known Observable design pattern.</li>
 * </ul>
 * 
 * @author jernlas
 *
 */
public interface AnalyzableText {

   /**
    * Adds a new TextAnalyzer
    * @param analyzer The analyzer to add
    */
   public void addAnalyzer(TextAnalyzer analyzer);
   
   /**
    * Removes a TextAnalyzer from the internal list of analyzers. 
    * This operation should allways be allowed (ie. all implementers must 
    * defensively copy the list before calling external code).
    * @param analyzer The analyzer to remove
    */
   public void removeAnalyzer(TextAnalyzer analyzer);
   
   /**
    * Gets the text that is to be used for any analysis by the TextAnalyzers.
    * @return The text selected for analysis.
    */
   public String getText();
   
}
